SelfData class

Annotations
  • @HiveType.new(typeId: 5)

Constructors

SelfData({String? id, String? name, String? namespace, String? type, String? icon, String? short_description, String? terms_of_service, String? privacy_policy, String? company_name, String? support_email, String? support_phone, String? support_website, String? website, String? street, String? city, String? state, String? zip, String? country, SelfDataAllowed_locations? allowed_locations, String? gateway_api_url})
SelfData.fromJson(Map<String, dynamic> json)

Properties

allowed_locations ↔ SelfDataAllowed_locations?
getter/setter pair
box → BoxBase?
Get the box in which this object is stored. Returns null if object has not been added to a box yet.
no setterinherited
city ↔ String?
getter/setter pair
company_name ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
gateway_api_url ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
getter/setter pair
id ↔ String?
getter/setter pair
isInBox → bool
Returns whether this object is currently stored in a box.
no setterinherited
key → dynamic
Get the key associated with this object. Returns null if object has not been added to a box yet.
no setterinherited
name ↔ String?
getter/setter pair
namespace ↔ String?
getter/setter pair
privacy_policy ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
short_description ↔ String?
getter/setter pair
state ↔ String?
getter/setter pair
street ↔ String?
getter/setter pair
support_email ↔ String?
getter/setter pair
support_phone ↔ String?
getter/setter pair
support_website ↔ String?
getter/setter pair
terms_of_service ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
website ↔ String?
getter/setter pair
zip ↔ String?
getter/setter pair

Methods

delete() → Future<void>
Deletes this object from the box it is stored in.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Future<void>
Persists this object.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited